.. include:: ../references.txt

Photometry Processing
=====================

.. TODO:: Write photometry documentation

Photometry API
--------------

.. automodapi:: astropop.photometry
    :no-inheritance-diagram:
